@@ -4,7 +4,7 @@
 //  Tree control used for the survey tree.
 //
 //  Copyright (C) 2001, Mark R. Shinwell.
-//  Copyright (C) 2001-2003,2005,2006,2016,2018 Olly Betts
+//  Copyright (C) 2001-2003,2005,2006,2016,2018,2025 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -120,18 +120,14 @@ BEGIN_EVENT_TABLE(AvenTreeCtrl, wxTreeCtrl)
     EVT_MENU(menu_SURVEY_HIDE, AvenTreeCtrl::OnHide)
     EVT_MENU(menu_SURVEY_SHOW, AvenTreeCtrl::OnShow)
     EVT_MENU(menu_SURVEY_HIDE_SIBLINGS, AvenTreeCtrl::OnHideSiblings)
+    EVT_MENU(wxID_FIND, AvenTreeCtrl::OnFind)
     EVT_TREE_STATE_IMAGE_CLICK(wxID_ANY, AvenTreeCtrl::OnStateClick)
 END_EVENT_TABLE()
 
 AvenTreeCtrl::AvenTreeCtrl(MainFrm* parent, wxWindow* window_parent) :
     wxTreeCtrl(window_parent, wxID_ANY, wxDefaultPosition, wxDefaultSize,
 	       wxTR_DEFAULT_STYLE | wxTR_HIDE_ROOT),
-    m_Parent(parent),
-    m_Enabled(false),
-    m_LastItem(),
-    m_BackgroundColour(),
-    m_SelValid(false),
-    menu_data(NULL)
+    m_Parent(parent)
 {
     wxImageList* img_list = new wxImageList(15, 15, 2);
     img_list->Add(wxBitmap(blank_xpm));
@@ -374,6 +370,9 @@ void AvenTreeCtrl::OnMenu(wxTreeEvent& e)
 	PopupMenu(&menu);
     } else if (data->IsStation()) {
 	// Station: name is data->GetLabel()->GetText()
+	wxMenu menu;
+	menu.Append(wxID_FIND, wmsg(/*Find*/332));
+	PopupMenu(&menu);
     } else if (ItemHasChildren(menu_item)) {
 	// Survey:
 	wxMenu menu;
@@ -403,6 +402,7 @@ void AvenTreeCtrl::OnMenu(wxTreeEvent& e)
 		break;
 #endif
 	}
+	menu.Append(wxID_FIND, wmsg(/*Find*/332));
 	PopupMenu(&menu);
     } else {
 	// Overlay - FIXME: menu here?
@@ -560,6 +560,13 @@ void AvenTreeCtrl::OnHideSiblings(wxCommandEvent&)
     m_Parent->ForceFullRedraw();
 }
 
+void AvenTreeCtrl::OnFind(wxCommandEvent&)
+{
+    // Shouldn't be available for the root item.
+    wxASSERT(menu_data);
+    m_Parent->TreeItemSearch(GetItemData(menu_item));
+}
+
 void AvenTreeCtrl::OnStateClick(wxTreeEvent& e)
 {
     auto item = e.GetItem();
