@@ -4,7 +4,7 @@
 //  Main frame handling for Aven.
 //
 //  Copyright (C) 2000-2003,2005 Mark R. Shinwell
-//  Copyright (C) 2001-2024 Olly Betts
+//  Copyright (C) 2001-2025 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -156,10 +156,10 @@ class AvenPresList;
 
 class MainFrm : public wxFrame, public Model {
     wxFileHistory m_history;
-    int m_SashPosition;
+    int m_SashPosition = -1;
     bool was_showing_sidepanel_before_fullscreen;
-    GfxCore* m_Gfx;
-    wxWindow* m_Log;
+    GfxCore* m_Gfx = nullptr;
+    wxWindow* m_Log = nullptr;
     GUIControl* m_Control;
     wxSplitterWindow* m_Splitter;
     AvenTreeCtrl* m_Tree;
@@ -176,12 +176,19 @@ class MainFrm : public wxFrame, public Model {
     wxString here_text, coords_text, dist_text, distfree_text;
 
     int m_NumHighlighted = 0;
-    bool pending_find;
+    enum {
+	PENDING_FIND_NONE,
+	PENDING_FIND,
+	PENDING_FIND_AND_GO } pending_find = PENDING_FIND_NONE;
 
-    bool fullscreen_showing_menus;
+    bool fullscreen_showing_menus = false;
+
+#ifdef __WXMAC__
+    bool using_macos_full_screen_view = false;
+#endif
 
 #ifdef PREFDLG
-    PrefsDlg* m_PrefsDlg;
+    PrefsDlg* m_PrefsDlg = nullptr;
 #endif
 
     bool ProcessSVXFile(const wxString & file);
@@ -431,6 +438,7 @@ public:
     void ShowInfo(const LabelInfo *here = NULL, const LabelInfo *there = NULL);
     void DisplayTreeInfo(const wxTreeItemData* data = NULL);
     void TreeItemSelected(const wxTreeItemData* data);
+    void TreeItemSearch(const wxTreeItemData* item);
     PresentationMark GetPresMark(int which);
     bool Animating() const { return m_Gfx && m_Gfx->Animating(); }
 
