@@ -32,14 +32,14 @@ extern "C" {
 #define STDERR stdout
 
 #define CHARSET_BAD        -1
-#define CHARSET_USASCII     0
+#define CHARSET_UTF8	    0
 #define CHARSET_ISO_8859_1  1
-#define CHARSET_DOSCP850    2
-#define CHARSET_UTF8	    4
-#define CHARSET_WINCP1252   5
-#define CHARSET_ISO_8859_15 6
-#define CHARSET_ISO_8859_2  8
-#define CHARSET_WINCP1250   9
+#define CHARSET_ISO_8859_2  2
+#define CHARSET_USASCII     3
+#define CHARSET_WINCP1250   4
+#define CHARSET_DOSCP850    5
+#define CHARSET_WINCP1252   6
+#define CHARSET_ISO_8859_15 15
 
 extern int msg_warnings; /* keep track of how many warnings we've given */
 extern int msg_errors;   /* and how many (non-fatal) errors */
@@ -93,7 +93,7 @@ int select_charset(int charset_code);
  */
 #ifdef MSG_SETUP_PROJ_SEARCH_PATH
 /* We only need this on these platforms. */
-# if OS_WIN32
+# ifdef _WIN32
 #  include <proj.h>
 #  define msg_init(ARGV) do {\
 	(msg_init)(ARGV); \
