@@ -2,7 +2,7 @@
  * Export from Aven as Survex .pos or .csv.
  */
 
-/* Copyright (C) 2005,2013,2014,2015,2018 Olly Betts
+/* Copyright (C) 2005-2024 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,10 +40,10 @@ class POS : public ExportFilter {
   public:
     POS(char separator_, bool csv_) : separator(separator_), csv(csv_) { }
     ~POS();
-    const int * passes() const;
+    const int * passes() const override;
     void header(const char *, const char *, time_t,
 		double, double, double,
-		double, double, double);
-    void label(const img_point *, const wxString&, bool, int);
-    void footer();
+		double, double, double) override;
+    void label(const img_point *, const wxString&, int, int) override;
+    void footer() override;
 };
